summaryrefslogtreecommitdiff
path: root/src/mesa/drivers/windows/wmesa.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/mesa/drivers/windows/wmesa.c')
-rw-r--r--src/mesa/drivers/windows/wmesa.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mesa/drivers/windows/wmesa.c b/src/mesa/drivers/windows/wmesa.c
index 8d59cff203..bd91040221 100644
--- a/src/mesa/drivers/windows/wmesa.c
+++ b/src/mesa/drivers/windows/wmesa.c
@@ -1,4 +1,4 @@
-/* $Id: wmesa.c,v 1.38 2002/10/04 19:10:11 brianp Exp $ */
+/* $Id: wmesa.c,v 1.39 2002/10/11 17:41:05 brianp Exp $ */
/*
* Windows (Win32) device driver for Mesa 3.4
@@ -582,9 +582,9 @@ static void enable( GLcontext* ctx, GLenum pname, GLboolean enable )
static void set_buffer(GLcontext *ctx, GLframebuffer *colorBuffer,
- GLenum buffer )
+ GLuint bufferBit )
{
/* XXX todo - examine buffer and set read/write pointers */
return;
}
@@ -582,9 +582,9 @@ static void enable( GLcontext* ctx, GLenum pname, GLboolean enable )
{
- /* XXX todo - examine buffer and set read/write pointers */
+ /* XXX todo - examine bufferBit and set read/write pointers */
return;
}